@@ -4,7 +4,7 @@ This module implements a client for the BloomD server.
 from __future__ import unicode_literals
 
 __all__ = ["BloomdError", "BloomdConnection", "BloomdClient", "BloomdFilter"]
-__version__ = "0.4.7"
+__version__ = "0.4.8"
 import logging
 import socket
 import errno
@@ -65,9 +65,9 @@ class BloomdConnection(object):
         if self.sock is None:
             self.sock = self._create_socket()
         sent = False
-        for attempt in xrange(self.attempts):
+        for attempt in range(self.attempts):
             try:
-                self.sock.sendall(cmd + "\n")
+                self.sock.sendall(str.encode(cmd + '\n'))
                 sent = True
                 break
             except socket.error as e:
@@ -116,7 +116,7 @@ class BloomdConnection(object):
         and reads the response, performing a retry if necessary.
         """
         done = False
-        for attempt in xrange(self.attempts):
+        for attempt in range(self.attempts):
             try:
                 self.send(cmd)
                 return self.read()
